==> radare2-1.5.0-1-armv7h.pkg.tar.xz: usr/include/libr/r_util.h <==
/* radare - LGPL - Copyright 2008-2016 - pancake */

#ifndef R2_UTIL_H
#define R2_UTIL_H

#include <r_types.h>
#include <r_diff.h>
#include <btree.h>
#include <r_regex.h>
#include <r_list.h> // radare linked list
#include <r_flist.h> // radare fixed pointer array iterators
#include <r_th.h>
#if !__WINDOWS__
#include <dirent.h>
#include <signal.h>
#endif
#ifdef HAVE_LIB_GMP
#include <gmp.h>
#endif
#if HAVE_LIB_SSL
#include <openssl/bn.h>
#endif
#ifdef _MSC_VER
#include <windows.h>
int gettimeofday (struct timeval* p, void* tz);
#endif
#include <sys/time.h>
#include "r_util/r_big.h"
#include "r_util/r_base64.h"
#include "r_util/r_base91.h"
#include "r_util/r_buf.h"
#include "r_util/r_bitmap.h"
#include "r_util/r_constr.h"
#include "r_util/r_debruijn.h"
#include "r_util/r_cache.h"
#include "r_util/r_des.h"
#include "r_util/r_file.h"
#include "r_util/r_hex.h"
#include "r_util/r_log.h"
#include "r_util/r_mem.h"
#include "r_util/r_mixed.h"
#include "r_util/r_name.h"
#include "r_util/r_num.h"
#include "r_util/r_graph.h"
#include "r_util/r_pool.h"
#include "r_util/r_punycode.h"
#include "r_util/r_queue.h"
#include "r_util/r_range.h"
#include "r_util/r_sandbox.h"
#include "r_util/r_signal.h"
#include "r_util/r_spaces.h"
#include "r_util/r_stack.h"
#include "r_util/r_str.h"
#include "r_util/r_strbuf.h"
#include "r_util/r_strpool.h"
#include "r_util/r_sys.h"
#include "r_util/r_tree.h"
#include "r_util/r_uleb128.h"
#include "r_util/r_utf8.h"
#include "r_util/r_id_storage.h"
#include "r_util/r_asn1.h"
#include "r_util/r_json.h"
#include "r_util/r_x509.h"
#include "r_util/r_pkcs7.h"

#ifdef __cplusplus
extern "C" {
#endif

R_LIB_VERSION_HEADER(r_util);

#ifdef __cplusplus
}
#endif

#endif

==> radare2-2.2.0-1-armv7h.pkg.tar.xz: usr/include/libr/r_util.h <==
/* radare - LGPL - Copyright 2008-2016 - pancake */

#ifndef R2_UTIL_H
#define R2_UTIL_H

#include <r_types.h>
#include <r_diff.h>
#include <btree.h>
#include <r_regex.h>
#include <r_list.h> // radare linked list
#include <r_skiplist.h> // skiplist
#include <r_flist.h> // radare fixed pointer array iterators
#include <r_th.h>
#if !__WINDOWS__
#include <dirent.h>
#include <signal.h>
#endif
#ifdef HAVE_LIB_GMP
#include <gmp.h>
#endif
#if HAVE_LIB_SSL
#include <openssl/bn.h>
#endif
#ifdef _MSC_VER
#include <windows.h>
int gettimeofday (struct timeval* p, void* tz);
#endif
#include <sys/time.h>
#include "r_util/r_addr_interval.h"
#include "r_util/r_rbtree.h"
#include "r_util/r_big.h"
#include "r_util/r_base64.h"
#include "r_util/r_base91.h"
#include "r_util/r_buf.h"
#include "r_util/r_bitmap.h"
#include "r_util/r_constr.h"
#include "r_util/r_debruijn.h"
#include "r_util/r_cache.h"
#include "r_util/r_des.h"
#include "r_util/r_file.h"
#include "r_util/r_hex.h"
#include "r_util/r_log.h"
#include "r_util/r_mem.h"
#include "r_util/r_mixed.h"
#include "r_util/r_name.h"
#include "r_util/r_num.h"
#include "r_util/r_graph.h"
#include "r_util/r_pool.h"
#include "r_util/r_punycode.h"
#include "r_util/r_queue.h"
#include "r_util/r_range.h"
#include "r_util/r_sandbox.h"
#include "r_util/r_signal.h"
#include "r_util/r_spaces.h"
#include "r_util/r_stack.h"
#include "r_util/r_str.h"
#include "r_util/r_strbuf.h"
#include "r_util/r_strpool.h"
#include "r_util/r_sys.h"
#include "r_util/r_tree.h"
#include "r_util/r_uleb128.h"
#include "r_util/r_utf8.h"
#include "r_util/r_utf16.h"
#include "r_util/r_utf32.h"
#include "r_util/r_id_storage.h"
#include "r_util/r_asn1.h"
#include "r_util/r_json.h"
#include "r_util/r_x509.h"
#include "r_util/r_pkcs7.h"

#ifdef __cplusplus
extern "C" {
#endif

R_LIB_VERSION_HEADER(r_util);

#ifdef __cplusplus
}
#endif

#endif
